# aiomq
渐进式异步任务构建服务，代码分服务端和客户端两个部分，用于快速构建异步任务，定时任务。支持结构有 队列，订阅/监听，分发，RPC。
可视化任务池界面，在线设备，手动触发，下发任务，上报任务。

版本要求
---

python: 3.8 以上
aiohttp


---

版本
---

0.2.0 事件基本任务注册和分发和基础的仪表盘, 支持多客户端

如果有更好建议或者写协作开发，请联系

联系方式: **sqxccdy@icloud.com**